@@ -272,7 +272,7 @@ namespace drawinglayer
                             nChars = nWidthToFill / nWidth;
 
                         String aFilled;
-                        aFilled.Fill( (USHORT)nChars, aText.GetChar( 0 ) );
+                        aFilled.Fill( (sal_uInt16)nChars, aText.GetChar( 0 ) );
                         aText = aFilled;
                         nPos = 0;
                         nLen = nChars;
@@ -766,9 +766,13 @@ namespace drawinglayer
             }
             else
             {
+                // remember that we enter a PolygonStrokePrimitive2D decomposition,
+                // used for AA thick line drawing
+                mnPolygonStrokePrimitive2D++;
+
                 mpOutputDevice->DrawPolyPolygon(aLocalPolyPolygon);
 
-                if(mnPolygonStrokePrimitive2D 
+                if(mnPolygonStrokePrimitive2D
                     && getOptionsDrawinglayer().IsAntiAliasing()
                     && (mpOutputDevice->GetAntialiasing() & ANTIALIASING_ENABLE_B2DDRAW))
                 {
@@ -783,6 +787,9 @@ namespace drawinglayer
                         mpOutputDevice->DrawPolyLine(aLocalPolyPolygon.getB2DPolygon(a), 0.0);
                     }
                 }
+
+                // leave PolygonStrokePrimitive2D
+                mnPolygonStrokePrimitive2D--;
             }
         }
 
@@ -1114,7 +1121,7 @@ namespace drawinglayer
                     
                     mpOutputDevice->EnableMapMode(false);
                     
-                    for(std::vector< basegfx::B2DPoint >::const_iterator aIter(rPositions.begin()); aIter != rPositions.end(); aIter++)
+                    for(std::vector< basegfx::B2DPoint >::const_iterator aIter(rPositions.begin()); aIter != rPositions.end(); ++aIter)
                     {
                         const basegfx::B2DPoint aDiscreteTopLeft((maCurrentTransformation * (*aIter)) - aDiscreteHalfSize);
                         const Point aDiscretePoint(basegfx::fround(aDiscreteTopLeft.getX()), basegfx::fround(aDiscreteTopLeft.getY()));
@@ -1134,7 +1141,7 @@ namespace drawinglayer
             const basegfx::BColor aRGBColor(maBColorModifierStack.getModifiedColor(rPointArrayCandidate.getRGBColor()));
             const Color aVCLColor(aRGBColor);
 
-            for(std::vector< basegfx::B2DPoint >::const_iterator aIter(rPositions.begin()); aIter != rPositions.end(); aIter++)
+            for(std::vector< basegfx::B2DPoint >::const_iterator aIter(rPositions.begin()); aIter != rPositions.end(); ++aIter)
             {
                 const basegfx::B2DPoint aViewPosition(maCurrentTransformation * (*aIter));
                 const Point aPos(basegfx::fround(aViewPosition.getX()), basegfx::fround(aViewPosition.getY()));
