@@ -226,12 +226,12 @@ CFilePreview* CFilePreview::createInstance(
         catch( CPreviewException& )
         {
             OSL_ASSERT( !s_FilePreviewInst );
-            OSL_ENSURE( sal_False, "Creation of the preview window failed" );
+            OSL_FAIL( "Creation of the preview window failed" );
         }
         catch( CAutoOleInit::COleInitException& )
         {
             OSL_ASSERT( !s_FilePreviewInst );
-            OSL_ENSURE( sal_False, "OleInitalize failed" );
+            OSL_FAIL( "OleInitalize failed" );
         }
     }
 
@@ -394,7 +394,7 @@ void SAL_CALL CFilePreview::enable( sal_Bool bEnable )
     m_bEnabled = bEnable;
     
     // force a redraw
-    InvalidateRect( m_hwnd, NULL, TRUE );
+    InvalidateRect( m_hwnd, NULL, sal_True );
     UpdateWindow( m_hwnd );	
 }
 
@@ -419,7 +419,7 @@ sal_Bool SAL_CALL CFilePreview::show( sal_Bool bShow )
 // if the preview is shown and enabled 
 // preview of the given file will be shown
 // returns true on success or false if an error
-// occured (the file in not there or not accessible etc.)
+// occurred (the file in not there or not accessible etc.)
 //---------------------------------------------------
 
 sal_Bool SAL_CALL CFilePreview::update( const rtl::OUString& aFileName )
@@ -436,7 +436,7 @@ sal_Bool SAL_CALL CFilePreview::update( const rtl::OUString& aFileName )
             loadFile( aFileName );
         
             // force a complete window redraw
-            InvalidateRect( m_hwnd, NULL, TRUE );
+            InvalidateRect( m_hwnd, NULL, sal_True );
             UpdateWindow( m_hwnd );	
         }
     }	
@@ -549,12 +549,12 @@ sal_Bool CFilePreview::loadFile( const rtl::OUString& aFileName )
         goto CLEANUP_AND_EXIT;
     
     hr = CreateStreamOnHGlobal(
-        hGlobal, FALSE, &pIStream );
+        hGlobal, sal_False, &pIStream );
 
     if ( SUCCEEDED( hr ) )
     {
         hr = OleLoadPicture(
-            pIStream, fsize, FALSE, 
+            pIStream, fsize, sal_False, 
             __uuidof( IPicture ), (LPVOID*)&m_IPicture );
     }
     
@@ -602,7 +602,7 @@ LRESULT CALLBACK CFilePreview::WndProc(
         // a result of handling WM_NCCREATE what
         // leads to a failure of CreateWindow[Ex]!!!
     case WM_NCCREATE:
-        lResult = TRUE;
+        lResult = sal_True;
         break;
 
     default:
