@@ -64,8 +64,8 @@
 #include "svx/framelink.hxx"
 #include "svx/sdr/table/tabledesign.hxx"
 #include "svx/svdundo.hxx"
-#include "svdstr.hrc"
-#include "svdglob.hxx"
+#include "svx/svdstr.hrc"
+#include "svx/svdglob.hxx"
 #include "editeng/writingmodeitem.hxx"
 #include "editeng/frmdiritem.hxx"
 #include "svx/xflhtit.hxx"
@@ -271,6 +271,7 @@ public:
 SdrTableObjImpl::SdrTableObjImpl()
 : mpTableObj( 0 )
 , mpLayouter( 0 )
+, mbModifyPending( false )
 {
 }
 
@@ -356,7 +357,7 @@ void SdrTableObjImpl::SetModel(SdrModel* /*pOldModel*/, SdrModel* pNewModel)
     }
     catch( Exception& )
     {
-        DBG_ERROR("svx::SdrTableObjImpl::SetModel(), exception caught!");
+        OSL_FAIL("svx::SdrTableObjImpl::SetModel(), exception caught!");
     }
 
     mxTableStyle = xNewTableStyle;
@@ -523,7 +524,7 @@ void SdrTableObjImpl::DragEdge( bool mbHorizontal, int nEdge, sal_Int32 nOffset
     }
     catch( Exception& )
     {
-        DBG_ERROR( "svx::SdrTableObjImpl::DragEdge(), exception caught!" );
+        OSL_FAIL( "svx::SdrTableObjImpl::DragEdge(), exception caught!" );
     }
 }
 
@@ -628,7 +629,7 @@ CellRef SdrTableObjImpl::getCell(  const CellPos& rPos  ) const
     }
     catch( Exception& )
     {
-        DBG_ERROR( "svx::SdrTableObjImpl::getCell(), exception caught!" );
+        OSL_FAIL( "svx::SdrTableObjImpl::getCell(), exception caught!" );
     }
     return xCell;
 }
@@ -757,7 +758,7 @@ SdrTableObj::SdrTableObj(SdrModel* _pModel, const ::Rectangle& rNewRect, sal_Int
 
 void SdrTableObj::init( sal_Int32 nColumns, sal_Int32 nRows )
 {
-    bClosedObj = TRUE;
+    bClosedObj = sal_True;
 
     mpImpl = new SdrTableObjImpl;
     mpImpl->acquire();
@@ -1168,7 +1169,7 @@ void SdrTableObj::InsertRows( sal_Int32 nIndex, sal_Int32 nCount /*= 1*/ )
     }
     catch( Exception& )
     {
-        DBG_ERROR("SdrTableObj::InsertRows(), exception caught!");
+        OSL_FAIL("SdrTableObj::InsertRows(), exception caught!");
     }
 }
 
@@ -1183,7 +1184,7 @@ void SdrTableObj::InsertColumns( sal_Int32 nIndex, sal_Int32 nCount /*= 1*/ )
     }
     catch( Exception& )
     {
-        DBG_ERROR("SdrTableObj::InsertColumns(), exception caught!");
+        OSL_FAIL("SdrTableObj::InsertColumns(), exception caught!");
     }
 }
 
@@ -1198,7 +1199,7 @@ void SdrTableObj::DeleteRows( sal_Int32 nIndex, sal_Int32 nCount /*= 1*/ )
     }
     catch( Exception& )
     {
-        DBG_ERROR("SdrTableObj::DeleteRows(), exception caught!");
+        OSL_FAIL("SdrTableObj::DeleteRows(), exception caught!");
     }
 }
 
@@ -1213,7 +1214,7 @@ void SdrTableObj::DeleteColumns( sal_Int32 nIndex, sal_Int32 nCount /*= 1*/ )
     }
     catch( Exception& )
     {
-        DBG_ERROR("SdrTableObj::DeleteColumns(), exception caught!");
+        OSL_FAIL("SdrTableObj::DeleteColumns(), exception caught!");
     }
 }
 
@@ -1400,34 +1401,34 @@ void SdrTableObj::onEditOutlinerStatusEvent( EditStatus* pEditStatus )
 
 void SdrTableObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
 {
-    rInfo.bResizeFreeAllowed=TRUE;
-    rInfo.bResizePropAllowed=TRUE;
-    rInfo.bRotateFreeAllowed=FALSE;
-    rInfo.bRotate90Allowed  =FALSE;
-    rInfo.bMirrorFreeAllowed=FALSE;
-    rInfo.bMirror45Allowed  =FALSE;
-    rInfo.bMirror90Allowed  =FALSE;
+    rInfo.bResizeFreeAllowed=sal_True;
+    rInfo.bResizePropAllowed=sal_True;
+    rInfo.bRotateFreeAllowed=sal_False;
+    rInfo.bRotate90Allowed  =sal_False;
+    rInfo.bMirrorFreeAllowed=sal_False;
+    rInfo.bMirror45Allowed  =sal_False;
+    rInfo.bMirror90Allowed  =sal_False;
 
     // allow transparence
-    rInfo.bTransparenceAllowed = TRUE;
+    rInfo.bTransparenceAllowed = sal_True;
 
     // gradient depends on fillstyle
     XFillStyle eFillStyle = ((XFillStyleItem&)(GetObjectItem(XATTR_FILLSTYLE))).GetValue();
     rInfo.bGradientAllowed = (eFillStyle == XFILL_GRADIENT);
-    rInfo.bShearAllowed     =FALSE;
-    rInfo.bEdgeRadiusAllowed=FALSE;
-    rInfo.bCanConvToPath    =FALSE;
-    rInfo.bCanConvToPoly    =FALSE;
-    rInfo.bCanConvToPathLineToArea=FALSE;
-    rInfo.bCanConvToPolyLineToArea=FALSE;
-    rInfo.bCanConvToContour = FALSE;
+    rInfo.bShearAllowed     =sal_False;
+    rInfo.bEdgeRadiusAllowed=sal_False;
+    rInfo.bCanConvToPath    =sal_False;
+    rInfo.bCanConvToPoly    =sal_False;
+    rInfo.bCanConvToPathLineToArea=sal_False;
+    rInfo.bCanConvToPolyLineToArea=sal_False;
+    rInfo.bCanConvToContour = sal_False;
 }
 
 // --------------------------------------------------------------------
 
-UINT16 SdrTableObj::GetObjIdentifier() const
+sal_uInt16 SdrTableObj::GetObjIdentifier() const
 {
-    return static_cast<UINT16>(OBJ_TABLE);
+    return static_cast<sal_uInt16>(OBJ_TABLE);
 }
 
 // --------------------------------------------------------------------
@@ -1461,7 +1462,7 @@ void SdrTableObj::SetModel(SdrModel* pNewModel)
 
 // --------------------------------------------------------------------
 
-void SdrTableObj::TakeTextRect( SdrOutliner& rOutliner, Rectangle& rTextRect, bool bNoEditText, Rectangle* pAnchorRect, BOOL bLineWidth ) const
+void SdrTableObj::TakeTextRect( SdrOutliner& rOutliner, Rectangle& rTextRect, bool bNoEditText, Rectangle* pAnchorRect, bool bLineWidth ) const
 {
     if( mpImpl )
         TakeTextRect( mpImpl->maEditPos, rOutliner, rTextRect, bNoEditText, pAnchorRect, bLineWidth );
@@ -1469,7 +1470,7 @@ void SdrTableObj::TakeTextRect( SdrOutliner& rOutliner, Rectangle& rTextRect, bo
 
 // --------------------------------------------------------------------
 
-void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, Rectangle& rTextRect, bool bNoEditText, Rectangle* pAnchorRect, BOOL /*bLineWidth*/ ) const
+void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, Rectangle& rTextRect, bool bNoEditText, Rectangle* pAnchorRect, bool /*bLineWidth*/ ) const
 {
     if( !mpImpl )
         return;
@@ -1484,7 +1485,7 @@ void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, Rec
     SdrTextVertAdjust eVAdj=xCell->GetTextVerticalAdjust();
 //	SdrTextHorzAdjust eHAdj=xCell->GetTextHorizontalAdjust();
 
-    ULONG nStat0=rOutliner.GetControlWord();
+    sal_uIntPtr nStat0=rOutliner.GetControlWord();
     Size aNullSize;
     nStat0 |= EE_CNTRL_AUTOPAGESIZE;
     rOutliner.SetControlWord(nStat0);
@@ -1520,7 +1521,7 @@ void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, Rec
             if( bHitTest ) // #i33696# take back fix #i27510#
                 rOutliner.SetTextObj( this );
 
-            rOutliner.SetUpdateMode(TRUE);
+            rOutliner.SetUpdateMode(sal_True);
             rOutliner.SetText(*pPara);
         }
     }
@@ -1532,7 +1533,7 @@ void SdrTableObj::TakeTextRect( const CellPos& rPos, SdrOutliner& rOutliner, Rec
     if (pEdtOutl && !bNoEditText && pPara && mpImpl->mxActiveCell == xCell )
         delete pPara;
 
-    rOutliner.SetUpdateMode(TRUE);
+    rOutliner.SetUpdateMode(sal_True);
     rOutliner.SetControlWord(nStat0);
 
     Point aTextPos(aAnkRect.TopLeft());
@@ -1617,7 +1618,7 @@ void SdrTableObj::setActiveCell( const CellPos& rPos )
     }
     catch( Exception& )
     {
-        DBG_ERROR("SdrTableObj::setActiveCell(), exception caught!");
+        OSL_FAIL("SdrTableObj::setActiveCell(), exception caught!");
     }
 }
 
@@ -1751,7 +1752,7 @@ void SdrTableObj::TakeTextEditArea( const CellPos& rPos, Size* pPaperMin, Size*
 
 // --------------------------------------------------------------------
 
-USHORT SdrTableObj::GetOutlinerViewAnchorMode() const
+sal_uInt16 SdrTableObj::GetOutlinerViewAnchorMode() const
 {
     EVAnchorMode eRet=ANCHOR_TOP_LEFT;
     CellRef xCell( getActiveCell() );
@@ -1808,7 +1809,7 @@ USHORT SdrTableObj::GetOutlinerViewAnchorMode() const
         }
 */
     }
-    return (USHORT)eRet;
+    return (sal_uInt16)eRet;
 }
 
 // --------------------------------------------------------------------
@@ -1850,84 +1851,6 @@ struct ImplTableShadowPaintInfo
 
 // --------------------------------------------------------------------
 
-void lcl_VertLineEnds( OutputDevice& rDev, const Point& rTop, const Point& rBottom,
-        const Color& rColor, long nXOffs, long nWidth,
-        const svx::frame::Style& rTopLine, const svx::frame::Style& rBottomLine )
-{
-    rDev.SetLineColor(rColor);              // PEN_NULL ???
-    rDev.SetFillColor(rColor);
-
-    //	Position oben/unten muss unabhaengig von der Liniendicke sein,
-    //	damit der Winkel stimmt (oder X-Position auch anpassen)
-    long nTopPos = rTop.Y();
-    long nBotPos = rBottom.Y();
-
-    long nTopLeft = rTop.X() + nXOffs;
-    long nTopRight = nTopLeft + nWidth - 1;
-
-    long nBotLeft = rBottom.X() + nXOffs;
-    long nBotRight = nBotLeft + nWidth - 1;
-
-    //	oben abschliessen
-
-    if ( rTopLine.Prim() )
-    {
-        long nLineW = rTopLine.GetWidth();
-        if (nLineW >= 2)
-        {
-            Point aTriangle[3];
-            aTriangle[0] = Point( nTopLeft, nTopPos );		// wie aPoints[0]
-            aTriangle[1] = Point( nTopRight, nTopPos );		// wie aPoints[1]
-            aTriangle[2] = Point( rTop.X(), nTopPos - (nLineW - 1) / 2 );
-            Polygon aTriPoly( 3, aTriangle );
-            rDev.DrawPolygon( aTriPoly );
-        }
-    }
-
-    //	unten abschliessen
-
-    if ( rBottomLine.Prim() )
-    {
-        long nLineW = rBottomLine.GetWidth();
-        if (nLineW >= 2)
-        {
-            Point aTriangle[3];
-            aTriangle[0] = Point( nBotLeft, nBotPos );		// wie aPoints[3]
-            aTriangle[1] = Point( nBotRight, nBotPos );		// wie aPoints[2]
-            aTriangle[2] = Point( rBottom.X(), nBotPos - (nLineW - 1) / 2 + nLineW - 1 );
-            Polygon aTriPoly( 3, aTriangle );
-            rDev.DrawPolygon( aTriPoly );
-        }
-    }
-}
-
-void lcl_VertLine( OutputDevice& rDev, const Point& rTop, const Point& rBottom,
-                    const svx::frame::Style& rLine,
-                    const svx::frame::Style& rTopLine, const svx::frame::Style& rBottomLine,
-                    const Color* pForceColor )
-{
-    if( rLine.Prim() )
-    {
-        svx::frame::DrawVerFrameBorderSlanted( rDev, rTop, rBottom, rLine, pForceColor );
-
-        svx::frame::Style aScaled( rLine );
-        aScaled.ScaleSelf( 1.0 / cos( svx::frame::GetVerDiagAngle( rTop, rBottom ) ) );
-        if( pForceColor )
-            aScaled.SetColor( *pForceColor );
-
-        long nXOffs = (aScaled.GetWidth() - 1) / -2L;
-
-        lcl_VertLineEnds( rDev, rTop, rBottom, aScaled.GetColor(),
-            nXOffs, aScaled.Prim(), rTopLine, rBottomLine );
-
-        if( aScaled.Secn() )
-            lcl_VertLineEnds( rDev, rTop, rBottom, aScaled.GetColor(),
-                nXOffs + aScaled.Prim() + aScaled.Dist(), aScaled.Secn(), rTopLine, rBottomLine );
-    }
-}
-
-// --------------------------------------------------------------------
-
 void SdrTableObj::TakeObjNameSingul(XubString& rName) const
 {
     rName = ImpGetResStr(STR_ObjNameSingulTable);
@@ -1951,31 +1874,35 @@ void SdrTableObj::TakeObjNamePlural(XubString& rName) const
 
 // --------------------------------------------------------------------
 
-void SdrTableObj::operator=(const SdrObject& rObj)
+SdrTableObj* SdrTableObj::Clone() const
 {
+    return CloneHelper< SdrTableObj >();
+}
+
+SdrTableObj& SdrTableObj::operator=(const SdrTableObj& rObj)
+{
+    if( this == &rObj )
+        return *this;
     // call parent
     SdrObject::operator=(rObj);
 
-    const SdrTableObj* pTableObj = dynamic_cast< const SdrTableObj* >( &rObj );
-    if (pTableObj!=NULL)
-    {
-        TableModelNotifyGuard aGuard( mpImpl ? mpImpl->mxTable.get() : 0 );
+    TableModelNotifyGuard aGuard( mpImpl ? mpImpl->mxTable.get() : 0 );
 
-        maLogicRect = pTableObj->maLogicRect;
-        aRect = pTableObj->aRect;
-        aGeo = pTableObj->aGeo;
-        eTextKind = pTableObj->eTextKind;
-        bTextFrame = pTableObj->bTextFrame;
-        aTextSize = pTableObj->aTextSize;
-        bTextSizeDirty = pTableObj->bTextSizeDirty;
-        bNoShear = pTableObj->bNoShear;
-        bNoRotate = pTableObj->bNoRotate;
-        bNoMirror = pTableObj->bNoMirror;
-        bDisableAutoWidthOnDragging = pTableObj->bDisableAutoWidthOnDragging;
+    maLogicRect = rObj.maLogicRect;
+    aRect = rObj.aRect;
+    aGeo = rObj.aGeo;
+    eTextKind = rObj.eTextKind;
+    bTextFrame = rObj.bTextFrame;
+    aTextSize = rObj.aTextSize;
+    bTextSizeDirty = rObj.bTextSizeDirty;
+    bNoShear = rObj.bNoShear;
+    bNoRotate = rObj.bNoRotate;
+    bNoMirror = rObj.bNoMirror;
+    bDisableAutoWidthOnDragging = rObj.bDisableAutoWidthOnDragging;
 
-        if( pTableObj->mpImpl )
-            *mpImpl = *pTableObj->mpImpl;
-    }
+    if( rObj.mpImpl )
+        *mpImpl = *rObj.mpImpl;
+    return *this;
 }
 
 // --------------------------------------------------------------------
@@ -2045,14 +1972,14 @@ sal_Bool SdrTableObj::BegTextEdit(SdrOutliner& rOutl)
 
 //	ForceOutlinerParaObject();
 
-    mbInEditMode = TRUE;
+    mbInEditMode = sal_True;
 
     rOutl.Init( OUTLINERMODE_TEXTOBJECT );
     rOutl.SetRefDevice( pModel->GetRefDevice() );
 
 // --
         bool bUpdMerk=rOutl.GetUpdateMode();
-        if (bUpdMerk) rOutl.SetUpdateMode(FALSE);
+        if (bUpdMerk) rOutl.SetUpdateMode(sal_False);
         Size aPaperMin;
         Size aPaperMax;
         Rectangle aEditArea;
@@ -2062,10 +1989,10 @@ sal_Bool SdrTableObj::BegTextEdit(SdrOutliner& rOutl)
         rOutl.SetMaxAutoPaperSize(aPaperMax);
         rOutl.SetPaperSize(aPaperMax);
 
-        if (bUpdMerk) rOutl.SetUpdateMode(TRUE);
+        if (bUpdMerk) rOutl.SetUpdateMode(sal_True);
 //---
 
-    ULONG nStat=rOutl.GetControlWord();
+    sal_uIntPtr nStat=rOutl.GetControlWord();
 //	nStat	&= ~EE_CNTRL_AUTOPAGESIZE;
     nStat	|= EE_CNTRL_AUTOPAGESIZE;
     nStat	&=~EE_CNTRL_STRETCHING;
@@ -2094,7 +2021,7 @@ void SdrTableObj::EndTextEdit(SdrOutliner& rOutl)
 
         OutlinerParaObject* pNewText = 0;
         Paragraph* p1stPara = rOutl.GetParagraph( 0 );
-        UINT32 nParaAnz = rOutl.GetParagraphCount();
+        sal_uInt32 nParaAnz = rOutl.GetParagraphCount();
 
         if(p1stPara)
         {
@@ -2124,11 +2051,11 @@ void SdrTableObj::EndTextEdit(SdrOutliner& rOutl)
 
     pEdtOutl = 0;
     rOutl.Clear();
-    UINT32 nStat = rOutl.GetControlWord();
+    sal_uInt32 nStat = rOutl.GetControlWord();
     nStat &= ~EE_CNTRL_AUTOPAGESIZE;
     rOutl.SetControlWord(nStat);
 
-    mbInEditMode = FALSE;
+    mbInEditMode = sal_False;
 }
 
 // --------------------------------------------------------------------
@@ -2236,7 +2163,7 @@ bool SdrTableObj::AdjustTextFrameWidthAndHeight(bool bHgt, bool bWdt)
 bool SdrTableObj::AdjustTextFrameWidthAndHeight(Rectangle& rR, bool bHeight, bool bWidth) const
 {
     if((pModel == NULL) || rR.IsEmpty() || !mpImpl || !mpImpl->mxTable.is() )
-        return FALSE;
+        return sal_False;
 
     Rectangle aRectangle( rR );
     mpImpl->LayoutTable( aRectangle, !bWidth, !bHeight );
@@ -2244,11 +2171,11 @@ bool SdrTableObj::AdjustTextFrameWidthAndHeight(Rectangle& rR, bool bHeight, boo
     if( aRectangle != rR )
     {
         rR = aRectangle;
-        return TRUE;
+        return sal_True;
     }
     else
     {
-        return FALSE;
+        return sal_False;
     }
 }
 
@@ -2440,8 +2367,8 @@ void SdrTableObj::AddToHdlList(SdrHdlList& rHdlList) const
     rHdlList.AddHdl( pH = new SdrHdl(aRect.BottomCenter(),HDL_LOWER) ); pH->SetMoveOutside( true );
     rHdlList.AddHdl( pH = new SdrHdl(aRect.BottomRight(),HDL_LWRGT) ); pH->SetMoveOutside( true );
 
-    ULONG nHdlCount = rHdlList.GetHdlCount();
-    for( ULONG nHdl = 0; nHdl < nHdlCount; nHdl++ )
+    sal_uIntPtr nHdlCount = rHdlList.GetHdlCount();
+    for( sal_uIntPtr nHdl = 0; nHdl < nHdlCount; nHdl++ )
         rHdlList.GetHdl(nHdl)->SetObj((SdrObject*)this);
 }
 
@@ -2451,7 +2378,7 @@ SdrHdl* SdrTableObj::GetHdl(sal_uInt32 nHdlNum) const
 {
     // #i73248#
     // Warn the user that this is ineffective and show alternatives. Should not be used at all.
-    OSL_ENSURE(false, "SdrTableObj::GetHdl(): ineffective, use AddToHdlList instead (!)");
+    OSL_FAIL("SdrTableObj::GetHdl(): ineffective, use AddToHdlList instead (!)");
 
     // to have an alternative, get single handle using the ineffective way
     SdrHdl* pRetval = 0;
@@ -2620,7 +2547,7 @@ bool SdrTableObj::MovCreate(SdrDragStat& rStat)
     rStat.SetActionRect(aRect1);
     aRect=aRect1; // fuer ObjName
     SetBoundRectDirty();
-    bSnapRectDirty=TRUE;
+    bSnapRectDirty=sal_True;
     return true;
 }
 
@@ -2735,7 +2662,7 @@ SdrTableObj* SdrTableObj::CloneRange( const CellPos& rStart, const CellPos& rEnd
         }
         catch( Exception& )
         {
-            DBG_ERROR( "svx::SvxTableController::GetMarkedObjModel(), exception caught!" );
+            OSL_FAIL( "svx::SvxTableController::GetMarkedObjModel(), exception caught!" );
         }
     }
 
